@@ -2,104 +2,52 @@
 # housekeeping
 ########################################################################
 
-package FindBin::libs   v2.12.01;
-use v5.14;
-use strict;
-
-use FindBin;
+package FindBin::libs   v4.0.1;
+use v5.40;
 
 use File::Basename;
 
-use Carp    qw( croak                   );
-use Symbol  qw( qualify qualify_to_ref  );
+use Carp        qw( croak                   );
+use List::Util  qw( uniq first              );
+use Symbol      qw( qualify qualify_to_ref  );
 
 use File::Spec::Functions
 qw
 (
-    &splitpath
-    &splitdir
-    &catpath
-    &catdir
+    splitpath
+    splitdir
+    catpath
+    catdir
+    rel2abs
 );
 
-BEGIN
-{
-    # however... there have been complaints of 
-    # places where abs_path does not work. 
-    #
-    # if abs_path fails on the working directory
-    # then replace it with rel2abs and live with 
-    # possibly slower, redundant directories.
-    #
-    # the abs_path '//' hack allows for testing 
-    # broken abs_path on primitive systems that
-    # cannot handle the rooted system being linked
-    # back to itself.
-
-    use Cwd qw( &abs_path &cwd );
-
-    if
-    (
-        # abs_path has a fixed bug dealing with infinite
-        # recursion. if upping the version of Cwd does 
-        # not fix this then the only other test I can 
-        # think of is ( -e '/.' && -e '/..' && -e '/../.' )
-
-        eval 
-        {
-            abs_path '//';
-            abs_path cwd
-        }
-    )
-    {
-        # abs_path seems clean on this platform.
-    }
-    else
-    {
-        # abs_path seems to be having problems,
-        # fix is to stub it out.
-        #
-        # undef avoids nastygram.
-
-        my $ref = qualify_to_ref 'abs_path', __PACKAGE__;
-
-        my $sub = File::Spec::Functions->can( 'rel2abs' );
-
-        undef &{ $ref };
-
-        *$ref = $sub
-    };
-}
+use FindBin::Bin        qw( $Bin        );
+use FindBin::Parents    qw( dir_paths   );
 
 ########################################################################
-# package variables 
+# package variables
 ########################################################################
 
-my %defaultz = 
+my %defaultz =
 (
-    base    => 'lib',
-    use     => undef,
-    blib    => undef,   # prefer ./blib at the first level
+    base    => 'lib'
+  , use     => undef
+  , blib    => undef   # prefer ./blib at the first level
 
-    subdir  => '',      # add this subdir also if found.
-    subonly => undef,   # leave out lib's, use only subdir.
-    export  => undef,   # push variable into caller's space.
-    append  => undef,   # push onto existing array (vs. overwrite)
-    verbose => undef,   # boolean: print inputs, results.
-    debug   => undef,   # boolean: set internal breakpoints.
+  , subdir  => ''      # add this subdir also if found.
+  , subonly => undef   # leave out lib's, use only subdir.
+  , export  => undef   # push variable into caller's space.
+  , append  => undef   # push onto existing array (vs. overwrite)
+  , verbose => undef   # boolean: print inputs, results.
+  , debug   => undef   # boolean: set internal breakpoints.
 
-    print   => 1,       # display the results
+  , print   => 1       # display the results
 
-    p5lib   => undef,   # prefix PERL5LIB with the results
+  , p5lib   => undef   # prefix PERL5LIB with the results
 
-    ignore => '/,/usr', # dir's to skip looking for ./lib
+  , ignore => q{,usr} # dir's to skip looking for ./lib
 );
 
-# only new directories are used, ignore pre-loads
-# this with unwanted values.
-
-my %found = ();
-
 # saves passing this between import and $handle_args.
 
 my %argz    = ();
@@ -107,7 +55,7 @@ my $verbose = '';
 my $empty   = q{};
 
 ########################################################################
-# subroutines
+# utility subs
 ########################################################################
 
 # HAK ALERT: $Bin is an absolute path, there are cases
@@ -115,103 +63,118 @@ my $empty   = q{};
 # directory path for it on VMS. Fix is to unshift a leading
 # '' into @dirpath where the leading entry is true.
 
+my $append_dir
+= sub
+{
+    my $dir             = shift;
+    my ( $vol, $dirs )  = splitpath $dir, 1;
+    my $subpath         = catdir $dirs, @_;
+    my $path            = catpath $vol, $subpath;
+
+    $path
+};
+
 my $find_libs
 = sub
 {
-    my $base    = basename ( shift || $argz{ base } );
+    my $base    = basename ( shift // $argz{ base } );
+    my $subdir  = $argz{ subdir } // '';
+    my $subonly = defined $argz{ subonly } || defined $argz{ scalar };
+    my @found   = ();
+    my $ignorz  = $argz{ ignore };
 
-    my $subdir  = $argz{ subdir } || '';
-
-    my $subonly = defined $argz{ subonly };
-
-    # for some reason, RH Enterprise V/4 has a 
-    # trailing '/'; I havn't seen another copy of 
-    # FindBin that does this. fix is quick enough: 
-    # strip the trailing '/'.
-    #
-    # using a regex to extract the value untaints it
-    # (not useful for anything much, just helps the
-    # poor slobs stuck in taint mode).
-    #
-    # after that splitpath can grab the directory 
-    # portion for future use.
-
-    my ( $Bin ) = ( $argz{ Bin } =~ m{^ (.+) }xs );
-
-    print STDERR "\nSearching $Bin for '$base'...\n"
+    say STDERR "\nSearching $Bin for '$base' ($subdir)..."
     if $verbose;
 
-    my( $vol, $dir ) = splitpath $Bin, 1;
-
-    my @dirpath = splitdir $dir;
-
-    # fix for File::Spec::VMS missing the leading empty
-    # string on a split. this can be removed once File::Spec
-    # is fixed.
-
-    unshift @dirpath, '' if $dirpath[ 0 ];
-
-    my @libz    = ();
-
-    PATH:
-    for( 1 .. @dirpath )
+    my @search
+    = do
     {
-        # note that catpath is extraneous on *NIX; the 
-        # volume only means something on DOS- & VMS-based
-        # filesystems, and adding an empty basename on 
-        # *nix is unnecessary.
-        #
-        # HAK ALERT: the poor slobs stuck on windog have an
-        # abs_path that croaks on missing directories. have
-        # to eval the check for subdir's. 
+        my @dirz    = dir_paths $Bin, 1;
 
-        my $abs
-        = eval
+        say STDERR join "\n\t" => 'Parent Dirs:', @dirz
+        if $verbose;;
+
+        my ( $vol ) = splitpath $dirz[0];
+        my %skipz
+        = map
         {
-            abs_path
-            catpath $vol, ( catdir @dirpath, $base ), $empty
+            (
+                catpath
+                (
+                    $vol => $_->$append_dir( $base ) 
+                ) => 1
+            )
         }
-        || '';
+        $ignorz->@*;
 
-        my $sub
-        = $subdir
-        ? eval { abs_path ( catpath '', $abs, $subdir ) } || ''
-        : ''
-        ;
-
-        my @search = $subonly ? ( $sub ) : ( $abs, $sub );
-
-        for my $dir ( @search )
+        my @subz
+        = grep
         {
-            if( $dir && -d $dir && ! exists $found{ $dir } )
+            ! exists $skipz{ $_ }
+        }
+        map
+        {
+            $_->$append_dir( $base )
+        }
+        @dirz;
+
+        say STDERR join "\n\t" => 'Search Subs:', @subz
+        if $verbose;;
+
+        if( $subdir )
+        {
+            map
             {
-                $found{ $dir } = ();
+                my $sub = $_->$append_dir( $subdir );
 
-                push @libz, $dir;
-
-                last if $argz{ scalar };
+                $subonly
+                ? $sub
+                : [ $sub => $_ ]
             }
+            @subz
         }
+        else
+        {
+            $subonly    = 1;
+            @subz
+        }
+    };
 
-        pop @dirpath
+    if( $argz{ scalar } )
+    {
+        # return at most one item.
+
+        first
+        {
+            -e
+        }
+        @search
     }
+    elsif( $subonly )
+    {
+        # grab all the extant items on the list.
 
-    # caller gets back the existing lib paths 
-    # (including volume) walking up the path 
-    # from $FindBin::Bin -> root.
-    #
-    # no libs found is empty list or undef for 
-    # scalar.
-    #
-    # passing it back as a list isn't all that
-    # painful for a few paths.
+        grep
+        {
+            -e
+        }
+        @search
+    }
+    else
+    {
+        # if the subdir exists then return it and the subdir.
 
-    wantarray ? @libz : \@libz
+        map
+        {
+            -e $_->[0]
+            ? $_->@*
+            : ()
+        }
+        @search
+    }
 };
 
-# break out the messy part into a separate block.
-
-my $handle_args 
+my $handle_args
 = sub
 {
     # discard the module, rest are arguments.
@@ -246,6 +209,12 @@ my $handle_args
     }
     @_;
 
+    # exporting a subdir as a scalar requires stopping at
+    # the subdir, ignoring its parent.
+
+    $argz{ subonly }
+    ||= $argz{ export } && $argz{ subdir } && $argz{ scalar };
+
     # stuff "debug=1" into your arguments and perl -d will stop here.
 
     $DB::single = 1 if defined $argz{ debug };
@@ -260,32 +229,13 @@ my $handle_args
     }
     elsif( defined $argz{ export } || defined $argz{ p5lib } )
     {
-        $argz{ use } = undef;
+        $argz{ use      } = undef;
     }
     else
     {
         $argz{ use } = 1;
     }
 
-    local $defaultz{ Bin }
-    = do
-    {
-        if( my $bin = $argz{ Bin } )
-        {
-            -d $bin
-            ? $bin
-            : -f $bin
-            ? dirname $bin
-            : die "Botched Bin: '$bin' neither file nor dir.\n";
-        }
-        else
-        {
-            exists $argz{ realbin }
-            ? $FindBin::RealBin
-            : $FindBin::Bin
-        }
-    };
-
     # now apply the defaults, then sanity check the result.
     # base is a special case since it always has to exist.
     #
@@ -294,7 +244,7 @@ my $handle_args
 
     while( my($k,$v) = each %defaultz )
     {
-        # //= doesn't work here since undef may be a 
+        # //= doesn't work here since undef may be a
         # legit default.
 
         exists $argz{ $k }
@@ -302,55 +252,42 @@ my $handle_args
         $argz{ $k } = $v;
     }
 
-    exists $argz{ base } && $argz{ base } 
+    exists $argz{ base } && $argz{ base }
     or croak "Bogus FindBin::libs: missing/false base argument, should be 'base=NAME'";
 
-    exists $argz{ export }
-    and
-    $argz{ export } //= $argz{ base };
+    $argz{ export } //= $argz{ base }
+    if exists $argz{ export };
 
     $argz{ ignore } =
     [
-        grep { $_ } split /\s*,\s*/, $argz{ ignore }
+        uniq split /\s*,\s*/, $argz{ ignore }
     ];
 
     $verbose = defined $argz{ verbose };
-
-    my $base = $argz{ base };
-
-    # now locate the libraries.
-    #
-    # %found contains the abs_path results for each directory to 
-    # avoid double-including directories.
-    #
-    # note: loop short-curcuts for the (usually) list.
-
-    %found = ();
-
-    for( @{ $argz{ ignore } } )
-    {
-        if( my $dir = eval { abs_path catdir $_, $base } )
-        {
-            if( -d $dir )
-            {
-                $found{ $dir } = 1;
-            }
-        }
-    }
 };
 
+########################################################################
+# interface
+########################################################################
+
 sub import
 {
     &$handle_args;
 
-    my @libz = $find_libs->();
-
     # HAK ALERT: the regex does nothing for security,
     # just dodges -T. putting this down here instead
     # of inside find_libs allows people to use saner
     # untainting plans via find_libs.
 
-    @libz   = map { m{ (.+) }xs } @libz;
+    my @libz
+    = map
+    {
+        m{ (.+) }xs
+    }
+    $find_libs->();
+
+    say join "\n\t" => 'Found Libs:', @libz
+    if $verbose;
 
     my $caller = caller;
 
@@ -359,7 +296,7 @@ sub import
         local $\ = "\n";
         local $, = "\n\t";
 
-        print STDERR "Found */$argz{ base }:", @libz
+        say STDERR "Found */$argz{ base }:", @libz
         if $verbose;
     }
 
@@ -376,14 +313,14 @@ sub import
             my $dest    = qualify $argz{ export }, $caller;
 
             $argz{ scalar }
-            ? print STDERR "\nExporting: \$$dest\n"
-            : print STDERR "\nExporting: \@$dest\n"
+            ? say STDERR "\nExporting: \$$dest"
+            : say STDERR "\nExporting: \@$dest"
             ;
         }
 
         if( $argz{ scalar } )
         {
-            *$ref 
+            *$ref
             = @libz
             ? \$libz[0]
             : \( my $a = '' )
@@ -391,7 +328,7 @@ sub import
         }
         elsif
         (
-            $argz{ append } 
+            $argz{ append }
             and
             my $ary = *{ $ref }{ ARRAY }
         )
@@ -416,13 +353,13 @@ sub import
 
             ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, '';
 
-            print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
+            say STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }"
             if $verbose;
         }
 
         if( $argz{ use } )
         {
-            # this obviously won't work if lib ever depends 
+            # this obviously won't work if lib ever depends
             # on the caller's package.
             #
             # it does avoids issues with -T blowing up on the
@@ -445,7 +382,7 @@ __END__
 
 =head1 NAME
 
-FindBin::libs - locate and a 'use lib' or export 
+FindBin::libs - locate and a 'use lib' or export
 directories based on $FindBin::Bin.
 
 =head1 SYNOPSIS
@@ -471,14 +408,6 @@ directories based on $FindBin::Bin.
 
     use FindBin::libs qw( Bin=/tmp base=altlib );
 
-    # if Bin is a file then it's dirname will be used.
-    # useful for ./t files living above files being 
-    # tested. __FILE__ is a token, doesn't work with
-    # qw().
-
-    use FindBin::libs ( 'Bin=' . __FILE__ );
-    use FindBin::libs ( 'Bin=' . __FILE__, 'base=config' );
-
     # skip "use lib", export "@altlib" instead.
 
     use FindBin::libs qw( base=altlib export );
@@ -498,7 +427,7 @@ directories based on $FindBin::Bin.
     use FindBin::libs qw( nouse noexport print  ); # print only
     use FindBin::libs qw( nouse noexport        ); # do nothting at all
 
-    # print a few interesting messages about the 
+    # print a few interesting messages about the
     # items found.
 
     use FindBinlibs qw( verbose );
@@ -529,9 +458,9 @@ directories based on $FindBin::Bin.
 
     use FindBin::libs qw( base=config subdir=mypackage subonly export );
 
-    # base and subonly are also useful if your 
-    # project is stored in multiple git 
-    # repositories. 
+    # base and subonly are also useful if your
+    # project is stored in multiple git
+    # repositories.
     #
     # say you need libs under api_foo/lib from api_bar: a
     # base of the git repository directory with subdir of
@@ -564,7 +493,7 @@ will turn off the default of "use lib" so that:
     use FindBin::libs qw( export );
     use FindBin::libs qw( p5lib  );
 
-are equivalent to 
+are equivalent to
 
     use FindBin::libs qw( export nouse );
     use FindBin::libs qw( p5lib  nouse );
@@ -587,15 +516,15 @@ will search for directories named "altlib" and "use lib" them.
 
 =item "export"
 
-This installs the results of locating directories into the caller's 
-space. Without any argument, export pushes out a variable named after 
-the located [sub]dir; an argument can be supplied to give the variable 
-name. Without the "scalar" option, the exported variable will be an 
-array in increasing order of "distance" (i.e., "up" the file tree); 
-with the "scalar" option only the first (i.e., "nearest") path is 
+This installs the results of locating directories into the caller's
+space. Without any argument, export pushes out a variable named after
+the located [sub]dir; an argument can be supplied to give the variable
+name. Without the "scalar" option, the exported variable will be an
+array in increasing order of "distance" (i.e., "up" the file tree);
+with the "scalar" option only the first (i.e., "nearest") path is
 exported.
 
-If "export" is given then "nouse" is assumed; using both leaves the 
+If "export" is given then "nouse" is assumed; using both leaves the
 variable exported and its contents handed to "use lib".
 
 For example:
@@ -610,7 +539,7 @@ list of directories found.
 will find "lib" directories and export them as "@mylibs" to
 the caller.
 
-If "export" only is given then the "use" option defaults to 
+If "export" only is given then the "use" option defaults to
 false. So:
 
     use FindBin::libs qw( export );
@@ -634,8 +563,8 @@ The use and export switches are not exclusive:
 
     use FindBin::libs qw( use export=mylibs );
 
-will locate "lib" directories, use lib them, and export 
-@mylibs into the caller's package. 
+will locate "lib" directories, use lib them, and export
+@mylibs into the caller's package.
 
 =item "scalar"
 
@@ -652,7 +581,7 @@ for "$etc/Foo.conf" rather than "$etc[0]/Foo.conf".
 
 =item "append"
 
-Sometimes it's simpler to accumulate multiple searches into a 
+Sometimes it's simpler to accumulate multiple searches into a
 single array. Say for ./etc dir's in collection of standard
 locations.
 
@@ -675,9 +604,9 @@ be overwritten with each call to import.
 
 =head3 Subdirectories
 
-The "subdir" and "subonly" settings will add or 
+The "subdir" and "subonly" settings will add or
 exclusively use subdir's. This is useful if some
-of your lib's are in ../lib/perl5 along with 
+of your lib's are in ../lib/perl5 along with
 ../lib or all of the lib's are in ../lib/perl5.
 
 These could be handled with:
@@ -713,9 +642,9 @@ order by distance from the #! code. At that point
 
     my $path = first { -e "$_/Global.config" } @etc;
 
-will locate the nearest "Global.confg" file. Note that this is 
-not the same as using "scalar" since that will export 
-$etc with only ./Foo/etc. 
+will locate the nearest "Global.confg" file. Note that this is
+not the same as using "scalar" since that will export
+$etc with only ./Foo/etc.
 
 =head3 Setting PERL5LIB: p5lib
 
@@ -759,12 +688,12 @@ will replace the standard list and thus skip "/skip/this/lib"
 and "/and/this/also/lib". It will search "/lib" and "/usr/lib"
 since the argument ignore list replaces the original one.
 
-=head2 Homegrown Library Management 
+=head2 Homegrown Library Management
 
 An all-too-common occurrance managing perly projects is
-being unable to install new modules becuse "it might 
+being unable to install new modules becuse "it might
 break things", and being unable to test them because
-you can't install them. The usual outcome of this is a 
+you can't install them. The usual outcome of this is a
 collection of hard-coded
 
     use lib qw( /usr/local/projectX ... )
@@ -793,11 +722,11 @@ having to modify a single line of code.
 Say your sandbox is in ./sandbox and you are currently
 working in ./sandbox/projects/package/bin on a perl
 executable. You may have some number of modules that
-are specific -- or customized -- for this pacakge, 
-share some modules within the project, and may want 
-to use company-wide modules that are managed out of 
-./sandbox in development. All of this lives under a 
-./qc tree on the test boxes and under ./production 
+are specific -- or customized -- for this pacakge,
+share some modules within the project, and may want
+to use company-wide modules that are managed out of
+./sandbox in development. All of this lives under a
+./qc tree on the test boxes and under ./production
 on production servers.
 
 For simplicity, say that your sandbox lives in your
@@ -823,10 +752,10 @@ This means that the most specific module directories
 ("closest" to your executable) will be picked up first.
 
 If you have a version of Frobnicate.pm in your ./package/lib
-for modifications fine: you'll use it before the one in 
-./project or ./sandbox. 
+for modifications fine: you'll use it before the one in
+./project or ./sandbox.
 
-Using the "p5lib" argument can help in case where some of 
+Using the "p5lib" argument can help in case where some of
 the code lives outside of the sandbox. To test a sandbox
 version of some other module:
 
@@ -838,17 +767,17 @@ and
 
 =item Regression Testing
 
-Everntually, however, you'll need to regression test 
-Frobnicate.pm with other modules. 
+Everntually, however, you'll need to regression test
+Frobnicate.pm with other modules.
 
 Fine: move, copy, or symlink it into ./project/lib and
-you can merrily run ./project/*/bin/* with it and see 
-if there are any problems. In fact, so can the nice 
-folks in QC. 
+you can merrily run ./project/*/bin/* with it and see
+if there are any problems. In fact, so can the nice
+folks in QC.
 
-If you want to install and test a new module just 
+If you want to install and test a new module just
 prefix it into, say, ./sandbox/lib and all the code
-that has FindBin::libs will simply use it first. 
+that has FindBin::libs will simply use it first.
 
 =item Testing with Symlinks
 
@@ -870,8 +799,8 @@ accomplished with a symlink:
 
 Running foobar symlinked into the post-change directory will
 test it with whatever collection of modules is in the post-change
-directory. A large regression test on some collection of 
-changed modules can be performed with a few symlinks into a 
+directory. A large regression test on some collection of
+changed modules can be performed with a few symlinks into a
 sandbox area.
 
 =item Managing Configuration and Meta-data Files
@@ -911,8 +840,8 @@ with
 
 Modules that are not intended for CPAN will not usually have
 a Makefile.PL or Build setup. This makes it harder to check
-the code via "make test". Instead of hacking a one-time 
-Makefile, FindBin::libs can be used to locate modules in 
+the code via "make test". Instead of hacking a one-time
+Makefile, FindBin::libs can be used to locate modules in
 a "lib" directory adjacent to the "t: directory. The setup
 for this module would look like:
 
@@ -923,7 +852,7 @@ for this module would look like:
 
     ./lib/FindBin/libs.pm
 
-since the *.t files use FindBin::libs they can locate the 
+since the *.t files use FindBin::libs they can locate the
 most recent version of code without it having to be copied
 into a ./blib directory (usually via make) before being
 processed. If the module did not have a Makefile this would
@@ -951,9 +880,9 @@ may be limited to *NIX or at least less portable.
 PERL5LIB can be used to accomplish the same directory
 lookups as FindBin::libs.  The problem is PERL5LIB often
 contains absolte paths and does not automatically change
-depending on where tests are run. This can leave you 
+depending on where tests are run. This can leave you
 modifying a file, changing directory to see if it works
-with some other code and testing an unmodified version of 
+with some other code and testing an unmodified version of
 the code via PERL5LIB. FindBin::libs avoids this by using
 $FindBin::bin to reference where the code is running from.
 
@@ -961,9 +890,9 @@ The same is true of trying to use almost any environmental
 solution, with Perl's built in mechanism or one based on
 $ENV{ PWD } or qx( pwd ).
 
-Aside: Combining an existing PERL5LIB for 
-out-of-tree lookups with the "p5lib" option 
-works well for most development situations. 
+Aside: Combining an existing PERL5LIB for
+out-of-tree lookups with the "p5lib" option
+works well for most development situations.
 
 =item use lib qw( ../../../../Lib );
 
@@ -988,10 +917,10 @@ something like:
     }
 
 This looks for a standard location (e.g., /path/to/Mylib)
-in the executable path (or cwd) and uses that. 
+in the executable path (or cwd) and uses that.
 
 The main problem here is that if the anchor ever changes
-(e.g., when moving code between projects or relocating 
+(e.g., when moving code between projects or relocating
 directories now that SVN supports it) the path often has
 to change in multiple files. The regex also may have to
 support multiple platforms, or be broken into more complicated
@@ -1005,46 +934,9 @@ does anyway.
 
 =head2 FindBin::libs-1.2+ uses File::Spec
 
-In order to accmodate a wider range of filesystems, 
+In order to accmodate a wider range of filesystems,
 the code has been re-written to use File::Spec for
-all directory and volume manglement. 
-
-There is one thing that File::Spec does not handle,
-hoever, which is fully reolving absolute paths. That
-still has to be handled via abs_path, when it works.
-
-The issue is that File::Spec::rel2abs and 
-Cwd::abs_path work differently: abs_path only 
-returns true for existing directories and 
-resolves symlinks; rel2abs simply prepends cwd() 
-to any non-absolute paths.
-
-The difference for FinBin::libs is that 
-including redundant directories can lead to 
-unexpected results in what gets included; 
-looking up the contents of heavily-symlinked 
-paths is slow (and has some -- admittedly 
-unlikely -- failures at runtime). So, abs_path() 
-is the preferred way to find where the lib's 
-really live after they are found looking up the 
-tree. Using abs_path() also avoids problems 
-where the same directory is included twice in a 
-sandbox' tree via symlinks.
-
-Due to previous complaints that abs_path did not 
-work properly on all systems, the current 
-version of FindBin::libs uses File::Spec to 
-break apart and re-assemble directories, with 
-abs_path used optinally. If "abs_path cwd" works 
-then abs_path is used on the directory paths 
-handed by File::Spec::catpath(); otherwise the 
-paths are used as-is. This may leave users on 
-systms with non-working abs_path() having extra
-copies of external library directories in @INC.
-
-Another issue is that I've heard reports of 
-some systems failing the '-d' test on symlinks,
-where '-e' would have succeded. 
+all directory and volume manglement.
 
 =head1 See Also
 
@@ -1052,13 +944,15 @@ where '-e' would have succeded.
 
 =item File::Spec
 
-This is used for portability in dis- and re-assembling 
+This is used for portability in dis- and re-assembling
 directory paths based on $FindBin::Bin.
 
 =item Older code.
 
 FindBin::libs_5_8.pm is installed if $^V indicates
-that the running perl is prior to v5.10.
+that the running perl is prior to v5.10. See the
+./versions dir in the distro for list of Perl version
+increments.
 
 =back
 
@@ -1066,16 +960,23 @@ that the running perl is prior to v5.10.
 
 =over 4
 
-=item 
+=item
 
 In order to avoid including junk, FindBin::libs
 uses '-d' to test the items before including
-them on the library list. This works fine so 
-long as abs_path() is used to disambiguate any
-symlinks first. If abs_path() is turned off
-then legitimate directories may be left off in
-whatever local conditions might cause a valid
-symlink to fail the '-d' test."
+them on the library list.
+
+abs_path causes too many issues where symlinks
+are useful, at this point I've given up trying
+to make it work. This may leave multiple paths
+to the same location in multiple points of the
+directory stack. So be it.
+
+This also means I've had to replace FindBin as
+the source of the execution directory. I've used
+a mirror of the Raku code for FindBin and
+FindBin::Parent here as seprate modules. These
+depend only on File::Spec and do not use abs_path.
 
 =item
 
@@ -1084,16 +985,16 @@ not returning an absolute paths in splitdir for
 dir's without a leading '.'. Fix for this is to
 unshift '', @dirpath if $dirpath[0]. While not a
 bug, this is obviously a somewhat kludgy workaround
-and should be removed (with an added test for a 
+and should be removed (with an added test for a
 working version) once the File::Spec is fixed.
 
-=item 
+=item
 
-The hack for prior-to-5.12 versions of perl is 
+The hack for prior-to-5.12 versions of perl is
 messy, but is the only I've found that works for
 the moment on *NIX, VMS, and MSW. I am not sure
 whether any of these systems are normally configured
-to share perl modules between versions. If the 
+to share perl modules between versions. If the
 moduels are not shared on multiple platforms then
 I can make this work by managing the installation
 rather than checking this every time at startup.
@@ -1102,41 +1003,15 @@ For the moment, at least, this seems to work.
 
 =back
 
-=head1 SEE ALSO
-
-=over 4
-
-=item Module::FromPerlVer
-
-Explains where the installed version comes from.
-
-=item File::Copy::Recursive
-
-Note: Due to issues with File::Copy::Recusive, this is
-using File::Copy::Recursive::Reduced and a version directory
-for the moment. Once the Recursive module has been dealt with
-Module::FromPerlVer shoud Just Work.
-
-=back
-
-=head2 Cwd
-
-A bug in Cwd was fixed with 3.73. That should, hopefully,
-fix the issue with FB::l croaking perl during testing.
-If it does not then I will have to modify the sanity check
-for using abs_path vs. rel2abs.
-
 =head1 AUTHOR
 
 Steven Lembark, Workhorse Computing <lembark@wrkhors.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2022, Steven Lembark, Workhorse Computing.
-This code is released under the same terms as Perl-5.24
-or any later version of Perl.
+Copyright (C) 2003-2024, Steven Lembark, Workhorse Computing.
 
 =head1 LICENSE
 
-This code is released under the same terms as Perl-5.24
+This code is released under the same terms as Perl-5.40
 or any later version of Perl.
